/* <<< Start of information >>>                                       */
/* ------------------------------------------------------------------ */
/* This file is part of the xwatch program. Copyright (C) Karel Kubat */
/* 1995. All rights reserved. You are permitted to redistribute this  */
/* package, if you include all unmodified sources and all unmodified  */
/* documentation (including this text). You are NOT permitted to      */
/* distribute files of this package with modifications. See the file  */
/* COPYING for more information. When in doubt, mail me at            */
/* karel@icce.rug.nl.                                                 */
/* ------------------------------------------------------------------ */
/* <<< End of information >>>                                         */

#include "xwatch.h"
#include "version.h" 

/* global data section */
Fileinfo
    *finfo = NULL;
int
    linelen,				/* length of display window */ 
    nfinfo = 0,				/* # of files */ 
    nlines,				/* lines to store */ 
    interval,				/* scanning interval */ 
    rescan = 0,				/* rescanning flag */ 
    printtime,				/* flag: print timestamp? */ 
    printname,				/* flag: print namestamp? */ 
    newline,				/* flag: print \n after stamps? */ 
    firstwarnings,			/* flag: print initial warnings? */
    foregr, backgr,			/* foreground/background indices */ 
    fred, fgreen, fblue,		/* r/g/b for foreground */
    width,				/* width of total window */
    fontstyle, fontsize;		/* currently used font */ 
Window
    curwindow;
FL_FORM
    *browser_form,
    *options_form;
FL_OBJECT
    *browser;

/* main function */ 
void main(int argc, char *argv[])
{
    int
	i;
    static int
	border,				/* flag: use border? */ 
	xpos, ypos,			/* startup screen coords */ 
	height,				/* initial height */ 
	bred, bgreen, bblue,		/* background r/g/b */ 
	printversion;			/* flag: print version/copyright? */
    static char
	*copyrightmsg [] =
	{
	    "\n",
	    "@l@i Xwatch V" VER "\n",
	    "\n",
	    "@i Copyright (c) Karel Kubat (karel@icce.rug.nl)\n",
	    "@i Another MegaHard production! All rights reserved.\n",
	    "\n",
	};

#include "flres.h"     
#include "settings.h"     

    /* count total cmdline length.. X barfs on too long cmdlines (!) */
#ifdef MAXCMDLINE
    register int
	totlength = 0;
    
    for (i = 0; i < argc; i++)
	totlength += strlen (argv [i]) + 1;
    if (totlength > MAXCMDLINE)
	error ("too many strings on the commandline");
#endif

    /* parse in options */
    fl_initialize ("XWatch", "XWatch", cmdopt,
		   sizeof (cmdopt) / sizeof (FL_CMD_OPT), &argc, argv);
    fl_get_app_resources (res, sizeof (res) / sizeof (FL_resource));

    /* check the settings */
    for (i = 0; i < sizeof (setting) / sizeof (Setting); i++)
	checksetting (*setting [i].var, setting [i].min,
		      setting [i].max, setting [i].desc);

    /* show usage if no args */
    if (argc < 2)
	usage ();

    /* now create and initialize the forms */
    foregr = getcolorindex (fred, fgreen, fblue);
    backgr = getcolorindex (bred, bgreen, bblue);

    create_browser_form ();

    /* fontsize is now 1..4, remap to 8/10/12/14 */
    fontsize <<= 1;
    fontsize += 6;
    fl_set_browser_fontsize (browser, fontsize);

    fl_set_browser_fontstyle (browser, fontstyle);

    /* show browser form */
    fl_set_form_geometry (browser_form, xpos, ypos, width, height);
    curwindow = fl_show_form (browser_form,
			      border ? FL_PLACE_FREE : FL_PLACE_POSITION,
			      border ? FL_FULLBORDER : FL_NOBORDER,
			      "Xwatch");

    /* add our own message */
    if (printversion)
	for (i = 0; i < sizeof (copyrightmsg) / sizeof (char *); i++)
	    warning (copyrightmsg [i]);

    /* add all files */
    for (i = 1; i < argc; i++)
	addfile (argv [i]);

    /* forms action loop , interrupted each `interval' secs */ 
    signal (SIGALRM, alarmhandler);
    alarm (interval);

    /* here goes..  */ 
    fl_do_forms();

    /* never reached, exit is from `quit' button */ 
}
